pheno-utils
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Viz functions, loaders, mergers.

WORK IN PROGRESS

## Install

``` sh
pip install pheno_utils
```

## How to use

Examples:

``` python
data = generate_synthetic_data(n=1000)
hist_ecdf_plots(data=data, col="val1")
```

    NameError: name 'hist_ecdf_plots' is not defined

``` python
age_refplots = GenderAgeRefPlot(data, "val1")
age_refplots.plot()
```
